==> Paws-0.35.tar.gz: Paws-0.35/lib/Paws/Config/ResourceCount.pm <==
package Paws::Config::ResourceCount;
  use Moose;
  has Count => (is => 'ro', isa => 'Int', request_name => 'count', traits => ['NameInRequest']);
  has ResourceType => (is => 'ro', isa => 'Str', request_name => 'resourceType', traits => ['NameInRequest']);
1;

### main pod documentation begin ###

=head1 NAME

Paws::Config::ResourceCount

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::Config::ResourceCount object:

  $service_obj->Method(Att1 => { Count => $value, ..., ResourceType => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::Config::ResourceCount object:

  $result = $service_obj->Method(...);
  $result->Att1->Count

=head1 DESCRIPTION

An object that contains the resource type and the number of resources.

=head1 ATTRIBUTES


=head2 Count => Int

  The number of resources.


=head2 ResourceType => Str

  The resource type, for example C<"AWS::EC2::Instance">.



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::Config>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: https://github.com/pplu/aws-sdk-perl

Please report bugs to: https://github.com/pplu/aws-sdk-perl/issues

=cut

==> Paws-0.41.tar.gz: Paws-0.41/lib/Paws/Config/ResourceCount.pm <==
package Paws::Config::ResourceCount;
  use Moose;
  has Count => (is => 'ro', isa => 'Int', request_name => 'count', traits => ['NameInRequest']);
  has ResourceType => (is => 'ro', isa => 'Str', request_name => 'resourceType', traits => ['NameInRequest']);
1;

### main pod documentation begin ###

=head1 NAME

Paws::Config::ResourceCount

=head1 USAGE

This class represents one of two things:

=head3 Arguments in a call to a service

Use the attributes of this class as arguments to methods. You shouldn't make instances of this class. 
Each attribute should be used as a named argument in the calls that expect this type of object.

As an example, if Att1 is expected to be a Paws::Config::ResourceCount object:

  $service_obj->Method(Att1 => { Count => $value, ..., ResourceType => $value  });

=head3 Results returned from an API call

Use accessors for each attribute. If Att1 is expected to be an Paws::Config::ResourceCount object:

  $result = $service_obj->Method(...);
  $result->Att1->Count

=head1 DESCRIPTION

An object that contains the resource type and the number of resources.

=head1 ATTRIBUTES


=head2 Count => Int

  The number of resources.


=head2 ResourceType => Str

  The resource type (for example, C<"AWS::EC2::Instance">).



=head1 SEE ALSO

This class forms part of L<Paws>, describing an object used in L<Paws::Config>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
